hotspot/src/share/vm/runtime/thread.cpp
changeset 23855 c4574075402c
parent 23542 e860dc279345
child 24331 c0bc7e5653fb
child 24322 c2978d1578e3
--- a/hotspot/src/share/vm/runtime/thread.cpp	Wed Mar 26 14:15:02 2014 +0100
+++ b/hotspot/src/share/vm/runtime/thread.cpp	Thu Apr 03 17:49:31 2014 +0400
@@ -1394,8 +1394,8 @@
 void JavaThread::initialize() {
   // Initialize fields
 
-  // Set the claimed par_id to -1 (ie not claiming any par_ids)
-  set_claimed_par_id(-1);
+  // Set the claimed par_id to UINT_MAX (ie not claiming any par_ids)
+  set_claimed_par_id(UINT_MAX);
 
   set_saved_exception_pc(NULL);
   set_threadObj(NULL);